@@ -75,7 +75,7 @@ where <- function(fn) {
 # copied and slightly rewritten from poorman under same license (2021-10-15)
 quick_case_when <- function (...) {
   fs <- list(...)
-  lapply(fs, function(x) if (class(x) != "formula") 
+  lapply(fs, function(x) if (!inherits(x, "formula"))
     stop("`case_when()` requires formula inputs."))
   n <- length(fs)
   if (n == 0L) 
