@@ -37,8 +37,8 @@ valid_mic_levels <- c(c(t(vapply(FUN.VALUE = character(9), ops,
                                  function(x) paste0(x, sort(c(1:9, 1.5)))))),
                       c(t(vapply(FUN.VALUE = character(45), ops,
                                  function(x) paste0(x, c(10:98)[9:98 %% 2 == TRUE])))),
-                      c(t(vapply(FUN.VALUE = character(16), ops,
-                                 function(x) paste0(x, sort(c(2 ^ c(7:11), 80 * c(2:12))))))))
+                      c(t(vapply(FUN.VALUE = character(17), ops,
+                                 function(x) paste0(x, sort(c(2 ^ c(7:11), 192, 80 * c(2:12))))))))
 
 #' Transform Input to Minimum Inhibitory Concentrations (MIC)
 #'
@@ -175,7 +175,7 @@ as.mic <- function(x, na.rm = FALSE) {
         unique() %pm>%
         sort() %pm>%
         vector_and(quotes = TRUE)
-      warning_(na_after - na_before, " results truncated (",
+      warning_("in `as.mic()`: ", na_after - na_before, " results truncated (",
                round(((na_after - na_before) / length(x)) * 100),
                "%) that were invalid MICs: ",
                list_missing, call = FALSE)
@@ -243,12 +243,12 @@ droplevels.mic <- function(x, exclude = if (any(is.na(levels(x)))) NULL else NA,
 pillar_shaft.mic <- function(x, ...) {
   crude_numbers <- as.double(x)
   operators <- gsub("[^<=>]+", "", as.character(x))
-  pasted <- trimws(paste0(operators, trimws(format(crude_numbers))))
-  out <- pasted
+  operators[!is.na(operators) & operators != ""] <- font_silver(operators[!is.na(operators) & operators != ""], collapse = NULL)
+  out <- trimws(paste0(operators, trimws(format(crude_numbers))))
   out[is.na(x)] <- font_na(NA)
-  out <- gsub("(<|=|>)", font_silver("\\1"), out)
-  out <- gsub("([.]?0+)$", font_white("\\1"), out)
-  create_pillar_column(out, align = "right", width = max(nchar(pasted)))
+  # maketrailing zeroes almost invisible
+  out[out %like% "[.]"] <- gsub("([.]?0+)$", font_white("\\1"), out[out %like% "[.]"], perl = TRUE)
+  create_pillar_column(out, align = "right", width = max(nchar(font_stripstyle(out))))
 }
 
 # will be exported using s3_register() in R/zzz.R
@@ -358,7 +358,7 @@ sort.mic <- function(x, decreasing = FALSE, ...) {
 #' @export
 #' @noRd
 hist.mic <- function(x, ...) {
-  warning_("Use `plot()` or ggplot2's `autoplot()` for optimal plotting of MIC values", call = FALSE)
+  warning_("in `hist()`: use `plot()` or ggplot2's `autoplot()` for optimal plotting of MIC values")
   hist(log2(x))
 }
 
